pyjabber.stanzas package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pyjabber.stanzas.error

Submodules
----------

pyjabber.stanzas.IQ module
--------------------------

.. automodule:: pyjabber.stanzas.IQ
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.stanzas.Message module
-------------------------------

.. automodule:: pyjabber.stanzas.Message
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.stanzas.Presence module
--------------------------------

.. automodule:: pyjabber.stanzas.Presence
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.stanzas
   :members:
   :undoc-members:
   :show-inheritance:
